@@ -36,7 +36,7 @@ except ImportError:  # pragma: no cover (py3 only)
 
 from pkg_resources import parse_version
 
-nodeenv_version = '0.13.4'
+nodeenv_version = '0.13.5'
 
 join = os.path.join
 abspath = os.path.abspath
@@ -390,7 +390,7 @@ def writefile(dest, content, overwrite=True, append=False):
         if append:
             logger.info(' * Appending data to %s', dest)
             with open(dest, 'ab') as f:
-                f.write(DISABLE_POMPT.encode('utf-8'))
+                f.write(DISABLE_PROMPT.encode('utf-8'))
                 f.write(content)
                 f.write(ENABLE_PROMPT.encode('utf-8'))
             return
@@ -505,7 +505,8 @@ def get_node_src_url_postfix(opt):
 
 
 def urlopen(url):
-    headers = {'User-Agent': 'nodeenv v.' + nodeenv_version}
+    home_url = "https://github.com/ekalinin/nodeenv/"
+    headers = {'User-Agent': 'nodeenv/%s (%s)' % (nodeenv_version, home_url)}
     req = urllib2.Request(url, None, headers)
     return urllib2.urlopen(req)
 
@@ -893,7 +894,7 @@ def main():
 # ---------------------------------------------------------
 # Shell scripts content
 
-DISABLE_POMPT = """
+DISABLE_PROMPT = """
 # disable nodeenv's prompt
 # (prompt already changed by original virtualenv's script)
 # https://github.com/ekalinin/nodeenv/issues/26
